==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/edit.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");

$out = new KWL_Html;
$VAR["Heading"] = _EDIT;
settype($return, "string");
if ($mode == "estory" && KWL_ValidRid($story)) {
	if ($return == "moderate.php") {
		if ($user['user_level'] != 1) KWL_ShowError(_PASS_NO);
	} else {
		if (!KWL_CheckPasswd("T_Stories",$story,$passwd) || !KWL_HcodeCheck($story.$mode, $hcode)) KWL_ShowError(_PASS_NO);
	}
	if ($delarticle) {	
		$sql = "DELETE FROM T_Stories";
		$deletefile = 1;	
	} else {
		if (empty($Summary)) $summ = KWL_genSummary($Content);
		else $summ = KWL_genSummary($Summary);
		$Content = chop(ltrim($Content));
		$summ = chop(ltrim($summ));
		list($Heading,$Author) = KWL_PrepareHtml($Heading,$Author);
		
		$AuthorEmail = KWL_EmailCheck($AuthorEmail);
		if ($AuthorURL) $AuthorURL = KWL_UrlCheck($AuthorURL);
		if ($CONF['SPAM_CHECK']==1) {
			KWL_SpamCheck($summ,$Author,$AuthorEmail);
			KWL_SpamCheck($Content,$Author,$AuthorEmail);
		} elseif ($CONF['SPAM_CHECK']==2) {
			$summ = KWL_ProofSpam($summ);
			$Content = KWL_ProofSpam($Content);
		}
		if (!$Author || !$AuthorEmail || !$Content || !$Heading) KWL_ShowError(_ERROR_INPUT);
		$tmp = $EmailComments=="on" ? "1" : "0";
		$sql	= "UPDATE T_Stories SET Topic=$Topic , Heading='$Heading' , Summary='$summ' , Content='$Content', Author='$Author', AuthorEmail='$AuthorEmail', AuthorURL='$AuthorURL', EmailComments = $tmp, ParseLevel = $ParseLevel";
		if (!empty($_FILES['userfile']['name'])) {
			$updir = date("YmdHis",time());
			$file = KWL_FileUpload($_FILES['userfile'],"$CONF[G_PATH]/upload/$Topic",$updir,$CONF['FILE_MAX_SIZE']);
			if (!is_array($file)) KWL_ShowError(_UPLOAD_FAILED);
			$sql .= ", bofile = '$file[name]', bcfile = '$updir', bfsize = '$file[size]'";
		} else if ($deletefile) $sql .= ", bofile = '', bcfile = '', bfsize = ''";
	}
	$sql .= " WHERE Rid = '$story'";

	if (SqlQuery($sql)) {
		if ($deletefile) {
			@unlink("upload/$oldtopic/$oldfile/$origfile");
			@rmdir("upload/$oldtopic/$oldfile");
		}
		KWL_StoryLink($Links,$story);
		if ($oldfile && $Topic != $oldtopic) {
			if (!file_exists("upload/$Topic")) mkdir("upload/$Topic",0755);
			exec("$exec[mv] \"upload/$oldtopic/$oldfile\" \"upload/$Topic/\"");
		}
		KWL_ExportRdf();
	}
	if ($return) KWL_Redirect("$return",1);
	else if ($delarticle) KWL_Redirect("$CONF[G_URL]");
	else KWL_Redirect("stories.php?story=$story");

} elseif ($mode == "cedit" && KWL_ValidRid($rid)) {
	$Content = trim($Content);
	if (empty($Content) || !KWL_HcodeCheck($rid.$pid.$sid,$hcode)) {
      KWL_ShowError(_ERROR_INPUT);
   } else {
		if (KWL_CheckPasswd("T_Comments",$rid,$passwd)) {
			$page = SqlCount("T_Blocks","Rid",$sid);
			if ($delreply && !SqlCount("T_Comments","ParentRid",$rid)) {
				$sql = "DELETE FROM T_Comments WHERE Rid = '$rid'";
				if ($page) $where = "$CONF[G_URL]/pages.php?page=$sid";
				else $where = "$CONF[G_URL]/?story=$sid";
			} else {
				if ($CONF['SPAM_CHECK']==1) {
					KWL_SpamCheck($Content,$Author,$AuthorEmail);
				} elseif ($CONF['SPAM_CHECK']==2) {
					$Content = KWL_ProofSpam($Content);
				}
				$sql = "UPDATE T_Comments SET Content='$Content', Birthstamp = now(), ParseLevel = $ParseLevel WHERE Rid = '$rid'";
				if ($page) $where = "$CONF[G_URL]/pages.php?page=$sid#$rid";
				else $where = "$CONF[G_URL]/comments.php?rid=$pid&story=$sid#$rid";
			}
			SqlQuery($sql);
			if (!$page) KWL_Update_Replys($sid);
		} else KWL_ShowError(_PASS_NO);
	}
	KWL_Redirect("$where");
} elseif (isset($story) && $mode == "story") {
	$head = _EDIT;
	include("include/header.inc.php");
   if (!empty($C_STORY)) $A =& $C_STORY;
	else $A = KWL_GetStory($story);

	if (!$A) {
		$VAR["Heading"] = _NOSTORY;
		$VAR["Content"] = "<br>" . _NOSTORY . "<br><br>";
		KWL_DrawMain($VAR);
	} else {
$VAR["Content"] = $out->form_start("edit.php","Edit",$CONF['FILE_UPLOAD']) 
. $out->table_start("100%",'',0,1,3) ."
<TR>
	<TD>* ". _AUTHOR . ":</TD>
	<TD>". $out->input_form("TEXT","Author",$A['Author'],$size['name'],32) ."</TD>
</TR>
<TR>
	<TD>* " . _EMAIL . ":</TD>
	<TD>". $out->input_form("TEXT","AuthorEmail",$A['AuthorEmail'],$size['name'],96) ."</TD>
</TR>
<TR>
	<TD>" . _URL . ":</TD>
	<TD>". $out->input_form("TEXT","AuthorURL",$A['AuthorURL'],$size['name'],96) ."</TD>
</TR>
<TR>
	<TD>* " . _TITLE . ":</TD>
	<TD>". $out->input_form("TEXT","Heading",$A['Heading'],$size['titl'],96) ."</TD>
</TR>
<TR>
	<TD>". _TOPIC . ":</TD>
	<TD>". $out->topicsel($A["Topic"],"post") ."
</TR>
<TR>
	<TD COLSPAN=2>". _SUMMARY . ":
	<BR>". $out->textarea("Summary",5,$size['text'],KWL_PrepareHtml($A['Summary'])) ."
</TR>
<TR>
	<TD COLSPAN=2>* ". _STORY .": ". KWL_FormResizer("Edit.Content",$size['text'],10) ."
   <BR>". $out->textarea("Content",10,$size['text'],KWL_PrepareHtml($A['Content'])) ."</TD>
</TR>
<TR>
   <TD COLSPAN=2>". KWL_MakeSelectParse($CONF['story_parse'],$A['ParseLevel']) ."
</TD>
</TR>\n";

if ($CONF['EmailComments']) {
   $VAR["Content"] .= "<TR>
      <TD COLSPAN=2>". $out->check_box("EmailComments",$A['EmailComments']) ." ". _MAILCOMMENTS . "</TD>
</TR>";
}

if (SqlCount("T_IndexNames")) {
   $VAR["Content"]	.= KWL_EditIndex($A["Rid"]);
}

if ($A['bofile']) {
	$VAR["Content"] .= "
<TR>
	<TD>". _ATTCHED_FILE .":</TD>
	<TD>
	<a href=\"$CONF[G_URL]/upload/$A[Topic]/$A[bcfile]/$A[bofile]\">"
	. KWL_icon_check($A['bofile']) ." ". $A['bofile'] ."</a> (". KWL_FileHSize($A['bfsize']) . ") ";
	$VAR["Content"] .= $out->check_box("deletefile") ." ". _DELETE_FILE 
	." ". $out->input_form("HIDDEN","origfile",$A['bofile']);

} else if ($CONF['FILE_UPLOAD']) {
	$VAR["Content"] .= "
<TR>
   <TD>"._FILE.":</TD>
   <TD>"
	. $out->input_form("HIDDEN","max_file_size",$CONF['FILE_MAX_SIZE'])
	. $out->input_form("file","userfile",'',KWL_FormSize(15),256) ."<BR>
</TD></TR>";
}

$VAR["Content"] .= "
<TR>
   <TD COLSPAN=2>"
   . $out->input_form("HIDDEN","oldtopic",$A['Topic'])
   . $out->input_form("HIDDEN","oldfile",$A['bcfile'])
   . $out->input_form("HIDDEN","story","$story")
   . $out->input_form("HIDDEN","mode","estory")
   . $out->input_form("HIDDEN","hcode",KWL_HcodeMake($story."estory"))
   . _PASSWD .": ". $out->input_form("password","passwd",'',KWL_FormSize(7),10) ."
   &nbsp;". $out->input_form("SUBMIT",'',_EDIT);

if (!SqlCount("T_Comments","TopRid",$A['Rid'])) 
	$VAR["Content"] .= $out->check_box("delarticle") . _DEL_STORY;
$VAR["Content"] .= "</TD></TR>". $out->table_end() . $out->form_end();

	KWL_DrawMain($VAR);
	}
include("include/footer.inc.php");

} elseif ($rid && $mode == "com") {
	$head = _EDIT;
	include("include/header.inc.php");
	$sql  = "SELECT * FROM T_Comments WHERE Rid = '$rid'";
	$A = SqlQueryFetchArray($sql);

	if (!is_array($A) || empty($A['AuthorEmail'])) {
		$VAR["Heading"] = _NOSTORY;
		$VAR["Content"] = "<br>" . _NOSTORY . "<br><br>";
		KWL_DrawMain($VAR);
	
   } else {

$VAR["Content"] = $out->form_start("edit.php","Com") . $out->table_start("100%") ."
<TR>
	<TD>" . _NAME . ":</TD>
	<TD>$A[Author]</TD>
</TR>
<TR>
	<TD>" . _EMAIL . ":</TD>
	<TD>". KWL_PrepareHtml($A['AuthorEmail']) ."</TD>
</TR>
<TR>
	<TD>" . _URL . "</TD>
   <TD>$A[AuthorURL]</TD>
</TR>
<TR>
	<TD COLSPAN=2>". _COMMENT .": ". KWL_FormResizer("Com.Content",$size['text'],10) ."
   <BR>
   ". $out->textarea("Content",10,$size['text'],KWL_PrepareHtml($A['Content'])) ."
   </TD>
</TR>
<TR>
   <TD COLSPAN=2>". KWL_MakeSelectParse($CONF['reply_parse'],$A['ParseLevel']) ."
   </TD>
</TR>
<TR>
	<TD COLSPAN=2>"
   . $out->input_form("HIDDEN","AuthorEmail",$A['AuthorEmail'])
   . $out->input_form("HIDDEN","Author",$A['Author'])
   . $out->input_form("HIDDEN","mode","cedit")
   . $out->input_form("HIDDEN","rid",$rid)
   . $out->input_form("HIDDEN","pid",$A['ParentRid'])
   . $out->input_form("HIDDEN","sid",$A['TopRid'])
   . $out->input_form("HIDDEN","where","comments.php?rid=$A[ParentRid]&story=$A[TopRid]#$rid")
   . $out->input_form("HIDDEN","hcode",KWL_HcodeMake($rid.$A['ParentRid'].$A['TopRid']))
   . _PASSWD . ": ". $out->input_form("password","passwd",'',KWL_FormSize(7),15)
   . "&nbsp;" . $out->input_form("SUBMIT",'',_EDIT);
	
if (!SqlCount("T_Comments","ParentRid",$A['Rid'])) 
	$VAR["Content"] .= $out->check_box("delreply") . _DEL_REPLY;

$VAR["Content"] .= "</TD></TR>". $out->table_end() . $out->form_end();
	KWL_DrawMain($VAR);
	}
include("include/footer.inc.php");
} else {
	KWL_Redirect("$CONF[G_URL]");
}

function KWL_Update_Replys($rid) {
	if (SqlCount("T_Stories","Rid",$rid)>0) {
		$replys = SqlCount("T_Comments","TopRid",$rid);
		$sql  = "SELECT Birthstamp FROM T_Comments WHERE TopRid = '$rid' ";
		$sql .= "ORDER By Birthstamp desc LIMIT 1";
		$lastrdate = SqlResult($sql);
		SqlQuery("LOCK TABLES T_Stories WRITE");
		SqlQuery("UPDATE T_Stories SET replys = $replys, lastrdate = '$lastrdate' WHERE Rid = '$rid'");
		SqlQuery("UNLOCK TABLES");
	}
}
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/edit.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");

$out = new KWL_Html;
$VAR["Heading"] = _EDIT;
settype($return, "string");
$delarticle = isset($_POST['delarticle']) ? $delarticle : false;
$deletefile = isset($_POST['deletefile']) ? $deletefile : false;
if ($mode == "estory" && KWL_ValidRid($story)) {
	if ($return == "moderate.php") {
		if ($user['user_level'] != 1) KWL_ShowError(_PASS_NO);
	} else {
		if (!KWL_CheckPasswd("T_Stories",$story,$passwd) || !KWL_HcodeCheck($story.$mode, $hcode)) KWL_ShowError(_PASS_NO);
	}
	if ($delarticle) {	
		$sql = "DELETE FROM T_Stories";
		$deletefile = 1;	
	} else {
		if (empty($Summary)) $summ = KWL_genSummary($Content);
		else $summ = KWL_genSummary($Summary);
		$Content = chop(ltrim($Content));
		$summ = chop(ltrim($summ));
		list($Heading,$Author) = KWL_PrepareHtml($Heading,$Author);
		
		$AuthorEmail = KWL_EmailCheck($AuthorEmail);
		if ($AuthorURL) $AuthorURL = KWL_UrlCheck($AuthorURL);
      if ($CONF['BLOCK_IP']) KWL_PostBlockIP($Content,$Author,$AuthorEmail);
      elseif ($CONF['SPAM_CHECK']==1) {
			KWL_SpamCheck($summ,$Author,$AuthorEmail);
			KWL_SpamCheck($Content,$Author,$AuthorEmail);
		} elseif ($CONF['SPAM_CHECK']==2) {
			$summ = KWL_ProofSpam($summ);
			$Content = KWL_ProofSpam($Content);
		}
		if (!$Author || !$AuthorEmail || !$Content || !$Heading) KWL_ShowError(_ERROR_INPUT);
		$tmp = $EmailComments=="on" ? "1" : "0";
		$sql	= "UPDATE T_Stories SET Topic=$Topic , Heading='$Heading' , Summary='$summ' , Content='$Content', Author='$Author', AuthorEmail='$AuthorEmail', AuthorURL='$AuthorURL', EmailComments = $tmp, ParseLevel = $ParseLevel";
		if (!empty($_FILES['userfile']['name'])) {
			$updir = date("YmdHis",time());
			$file = KWL_FileUpload($_FILES['userfile'],"$CONF[G_PATH]/upload/$Topic",$updir,$CONF['FILE_MAX_SIZE']);
			if (!is_array($file)) KWL_ShowError(_UPLOAD_FAILED);
			$sql .= ", bofile = '$file[name]', bcfile = '$updir', bfsize = '$file[size]'";
		} else if ($deletefile) $sql .= ", bofile = '', bcfile = '', bfsize = ''";
	}
	$sql .= " WHERE Rid = '$story'";

	if (SqlQuery($sql)) {
		if ($deletefile) {
			@unlink("upload/$oldtopic/$oldfile/$origfile");
         @unlink("upload/$oldtopic/$oldfile/$origfile"."_t.jpg");
			@rmdir("upload/$oldtopic/$oldfile");
		}
		KWL_StoryLink($Links,$story);
		if ($oldfile && $Topic != $oldtopic) {
			if (!file_exists("upload/$Topic")) mkdir("upload/$Topic",0755);
			exec("$exec[mv] \"upload/$oldtopic/$oldfile\" \"upload/$Topic/\"");
		}
		KWL_ExportRdf();
	}
	if ($return) KWL_Redirect("$return",1);
	else if ($delarticle) KWL_Redirect("$CONF[G_URL]");
	else KWL_Redirect("stories.php?story=$story");

} elseif ($mode == "cedit" && KWL_ValidRid($rid)) {
	$Content = trim($Content);
	if (empty($Content) || !KWL_HcodeCheck($rid.$pid.$sid,$hcode)) {
      KWL_ShowError(_ERROR_INPUT);
   } else {
		if (KWL_CheckPasswd("T_Comments",$rid,$passwd)) {
			$page = SqlCount("T_Blocks","Rid",$sid);
			if ($delreply && !SqlCount("T_Comments","ParentRid",$rid)) {
				$sql = "DELETE FROM T_Comments WHERE Rid = '$rid'";
				if ($page) $where = "$CONF[G_URL]/pages.php?page=$sid";
				else $where = "$CONF[G_URL]/?story=$sid";
			} else {
            if ($CONF['BLOCK_IP']) KWL_PostBlockIP($Content,$Author,$AuthorEmail);
            elseif ($CONF['SPAM_CHECK']==1) {
					KWL_SpamCheck($Content,$Author,$AuthorEmail);
				} elseif ($CONF['SPAM_CHECK']==2) {
					$Content = KWL_ProofSpam($Content);
				}
				$sql = "UPDATE T_Comments SET Content='$Content', Birthstamp = now(), ParseLevel = $ParseLevel WHERE Rid = '$rid'";
				if ($page) $where = "$CONF[G_URL]/pages.php?page=$sid#$rid";
				else $where = "$CONF[G_URL]/comments.php?rid=$pid&story=$sid#$rid";
			}
			SqlQuery($sql);
			if (!$page) KWL_Update_Replys($sid);
		} else KWL_ShowError(_PASS_NO);
	}
	KWL_Redirect("$where");
} elseif (isset($story) && $mode == "story") {
	$head = _EDIT;
	include("include/header.inc.php");
   if (!empty($C_STORY)) $A =& $C_STORY;
	else $A = KWL_GetStory($story);

	if (!$A) {
		$VAR["Heading"] = _NOSTORY;
		$VAR["Content"] = "<br />" . _NOSTORY . "<br /><br />";
		KWL_DrawMain($VAR);
	} else {
$VAR["Content"] = $out->form_start("edit.php","Edit",$CONF['FILE_UPLOAD']) 
. $out->table_start("100%",'',0,1,3) ."
<tr>
	<td>* ". _AUTHOR . ":</td>
	<td>". $out->input_form("text","Author",$A['Author'],$size['name'],32) ."</td>
</tr>";
if ($login) {
   $VAR["Content"] .= $out->input_form("hidden","AuthorEmail",$user['email']);
} else {
   $VAR["Content"] .= $out->input_form("hidden","AuthorEmail",$A['AuthorEmail']);
}
/*
<tr>
	<td>* " . _EMAIL . ":</td>
	<td>". $out->input_form("text","AuthorEmail",$A['AuthorEmail'],$size['name'],96) ."</td>
</tr>
*/
$VAR["Content"] .= "
<tr>
	<td>" . _URL . ":</td>
	<td>". $out->input_form("text","AuthorURL",$A['AuthorURL'],$size['name'],96) ."</td>
</tr>
<tr>
	<td>* " . _TITLE . ":</td>
	<td>". $out->input_form("text","Heading",$A['Heading'],$size['titl'],96) ."</td>
</tr>
<tr>
	<td>". _TOPIC . ":</td>
	<td>". $out->topicsel($A["Topic"],"post") ."
</tr>
<tr>
	<td colspan=\"2\">". _SUMMARY . ":
	<br />". $out->textarea("Summary",5,$size['text'],KWL_PrepareHtml($A['Summary'])) ."
</tr>
<tr>
	<td colspan=\"2\">* ". _STORY .": ". KWL_FormResizer("Edit.Content",$size['text'],10) ."
   <br />". $out->textarea("Content",10,$size['text'],KWL_PrepareHtml($A['Content'])) ."</td>
</tr>
<tr>
   <td colspan=\"2\">". KWL_MakeSelectParse($CONF['story_parse'],$A['ParseLevel']) ."
</td>
</tr>\n";

if ($CONF['EmailComments']) {
   $VAR["Content"] .= "<tr>
      <td colspan=\"2\">". $out->check_box("EmailComments",$A['EmailComments']) ." ". _MAILCOMMENTS . "</td>
</tr>";
}

if (SqlCount("T_IndexNames")) {
   $VAR["Content"]	.= KWL_EditIndex($A["Rid"]);
}

if ($A['bofile']) {
	$VAR["Content"] .= "
<tr>
	<td>". _ATTCHED_FILE .":</td>
	<td>
	<a href=\"$CONF[G_URL]/upload/$A[Topic]/$A[bcfile]/$A[bofile]\">"
	. KWL_icon_check($A['bofile']) ." ". $A['bofile'] ."</a> (". KWL_FileHSize($A['bfsize']) . ") ";
	$VAR["Content"] .= $out->check_box("deletefile") ." ". _DELETE_FILE 
	." ". $out->input_form("HIDDEN","origfile",$A['bofile']);

} else if ($CONF['FILE_UPLOAD']) {
	$VAR["Content"] .= "
<tr>
   <td>"._FILE.":</td>
   <td>"
	. $out->input_form("HIDDEN","max_file_size",$CONF['FILE_MAX_SIZE'])
	. $out->input_form("file","userfile",'',KWL_FormSize(15),256) ."<br />
</td></tr>";
}

$VAR["Content"] .= "
<tr>
   <td colspan=\"2\">"
   . $out->input_form("hidden","oldtopic",$A['Topic'])
   . $out->input_form("hidden","oldfile",$A['bcfile'])
   . $out->input_form("hidden","story","$story")
   . $out->input_form("hidden","mode","estory")
   . $out->input_form("hidden","hcode",KWL_HcodeMake($story."estory"))
   . _PASSWD .": ". $out->input_form("password","passwd",'',KWL_FormSize(7),10) ."
   &nbsp;". $out->input_form("SUBMIT",'',_EDIT);

if (!SqlCount("T_Comments","TopRid",$A['Rid'])) 
	$VAR["Content"] .= $out->check_box("delarticle") . _DEL_STORY;
$VAR["Content"] .= "</td></tr>". $out->table_end() . $out->form_end();

	KWL_DrawMain($VAR);
	}
include("include/footer.inc.php");

} elseif ($rid && $mode == "com") {
	$head = _EDIT;
	include("include/header.inc.php");
	$sql  = "SELECT * FROM T_Comments WHERE Rid = '$rid'";
	$A = SqlQueryFetchArray($sql);

	if (!is_array($A) || empty($A['AuthorEmail'])) {
		$VAR["Heading"] = _NOSTORY;
		$VAR["Content"] = "<br />" . _NOSTORY . "<br /><br />";
		KWL_DrawMain($VAR);
	
   } else {

$VAR["Content"] = $out->form_start("edit.php","Com") . $out->table_start("100%") ."
<tr>
	<td colspan=\"2\">" . _NAME . ": " . $A['Author'] ."</td>
</tr>
<tr>
	<td colspan=\"2\">". _COMMENT .": ". KWL_FormResizer("Com.Content",$size['text'],10) ."
   <br />
   ". $out->textarea("Content",10,$size['text'],KWL_PrepareHtml($A['Content'])) ."
   </td>
</tr>
<tr>
   <td colspan=\"2\">". KWL_MakeSelectParse($CONF['reply_parse'],$A['ParseLevel']) ."
   </td>
</tr>
<tr>
	<td colspan=\"2\">"
   . $out->input_form("hidden","AuthorEmail",$A['AuthorEmail'])
   . $out->input_form("hidden","Author",$A['Author'])
   . $out->input_form("hidden","mode","cedit")
   . $out->input_form("hidden","rid",$rid)
   . $out->input_form("hidden","pid",$A['ParentRid'])
   . $out->input_form("hidden","sid",$A['TopRid'])
   . $out->input_form("hidden","where","comments.php?rid=$A[ParentRid]&story=$A[TopRid]#$rid")
   . $out->input_form("hidden","hcode",KWL_HcodeMake($rid.$A['ParentRid'].$A['TopRid']))
   . _PASSWD . ": ". $out->input_form("password","passwd",'',KWL_FormSize(7),15)
   . "&nbsp;" . $out->input_form("SUBMIT",'',_EDIT);
	
if (!SqlCount("T_Comments","ParentRid",$A['Rid'])) 
	$VAR["Content"] .= $out->check_box("delreply") . _DEL_REPLY;

$VAR["Content"] .= "</td></tr>". $out->table_end() . $out->form_end();
	KWL_DrawMain($VAR);
	}
include("include/footer.inc.php");
} else {
	KWL_Redirect("$CONF[G_URL]");
}

function KWL_Update_Replys($rid) {
	if (SqlCount("T_Stories","Rid",$rid)>0) {
		$replys = SqlCount("T_Comments","TopRid",$rid);
		$sql  = "SELECT Birthstamp FROM T_Comments WHERE TopRid = '$rid' ";
		$sql .= "ORDER By Birthstamp desc LIMIT 1";
		$lastrdate = SqlResult($sql);
		SqlQuery("LOCK TABLES T_Stories WRITE");
		SqlQuery("UPDATE T_Stories SET replys = $replys, lastrdate = '$lastrdate' WHERE Rid = '$rid'");
		SqlQuery("UNLOCK TABLES");
	}
}
?>
